@@ -4,7 +4,7 @@ bool A2x::s_lastFail = false;
 
 using namespace std;
 
-int main(int argc)
+int main(int argc, char **argv)
 {
     cout << "Enter (nested) expressions ONLY consisting of *, + and "
                                                     "unary - operators.\n"
