@@ -2,8 +2,8 @@
 
 namespace{
 
-    typedef Parser::FunctionMap     FunMap;
-    typedef RuleValue::Function     Function;
+    using FunMap = Parser::FunctionMap;
+    using Function = RuleValue::Function;
 
 FunMap::value_type funArray[] = 
 {
@@ -31,7 +31,7 @@ FunMap::value_type funArray[] =
 unsigned const sizeofFunctionArray = sizeof(funArray) / 
                                             sizeof(FunMap::value_type);
 
-typedef Parser::DoubleMap::value_type DoubleValue;
+using DoubleValue = Parser::DoubleMap::value_type;
 
 DoubleValue doubleArray[] = 
 {
