@@ -7,7 +7,7 @@
 class RuleValue
 {
     public:
-        typedef std::vector<RuleValue>  Args;
+        using Args = std::vector<RuleValue>;
 
         struct Function
         {
