@@ -1,7 +1,6 @@
 #include "generator.ih"
 
-Generator::Generator(Rules const &rules, 
-                     unordered_map<string, string> const &polymorphic)
+Generator::Generator(Rules const &rules, StrStrMap &&polymorphic)
 :
     d_arg(Arg::instance()),
     d_rules(rules),
@@ -14,7 +13,7 @@ Generator::Generator(Rules const &rules,
     d_genDebug(d_options.genDebug()),
     d_printTokens(d_options.printTokens()),
     d_threadSafe(d_options.threadSafe()),
-    d_polymorphic(polymorphic),
+    d_polymorphic(move(polymorphic)),
 
     d_writer(d_baseClassScope, rules)
 {}
