@@ -17,7 +17,7 @@ void Generator::insert(ostream &out) const
     MapConstIter iter = s_insert.find(d_key);
 
     if (iter != s_insert.end())
-        (this->*iter->second)(out);
+        (this->*iter->second)(out);   // calls the specified s_insert function
     else
         wmsg << "Ignoring unsupported `$insert " << d_key << 
                 " ...' in skeleton file" << endl;
