@@ -5,6 +5,6 @@ void Parser::multiplyDefined(Symbol const *sp)
     Terminal::inserter(&Terminal::plainName);
     NonTerminal::inserter(&NonTerminal::plainName);
 
-    lineMsg(emsg) << (sp->isTerminal() ? "Terminal " : "Nonterminal ") << 
+    emsg << (sp->isTerminal() ? "Terminal " : "Nonterminal ") << 
                     sp  << " multiply defined" << endl;
 }
