@@ -7,8 +7,8 @@
 class RmShift
 {
     public:
-        typedef std::vector<RmShift>    Vector;
-        typedef Vector::const_iterator  ConstIter;
+        using Vector = std::vector<RmShift>;
+        using ConstIter = Vector::const_iterator;
 
     private:
         size_t d_idx;               // idx of the Next vector to remove.
