@@ -14,17 +14,17 @@ Terminal::Terminal(string const &name, Type type,
     d_readableLiteral(name),
     d_firstSet(this)
 {
-    if (name.find("'\\x") == 0)
+    if (name.find("'\\x") == 0UL)
     {
         int charRepresentation;
         istringstream convert(name.substr(3));
         convert >> hex >> charRepresentation;
         if (isprint(charRepresentation))
         {
-            d_readableLiteral = "'";
+            d_readableLiteral = "'"s;
             d_readableLiteral.append(1, static_cast<char>(charRepresentation));
             d_readableLiteral += "'";
-        }
+         }
     }
 
 // If the terminal definition is really requested (it isn't shown in bisonc++
